/*
 *                 Sun Public License Notice
 *
 * The contents of this file are subject to the Sun Public License
 * Version 1.0 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.sun.com/
 *
 *
 * The Original Code is NetBeans. The Initial Developer of the Original
 * Code is Tom Wheeler. Portions Copyright 2006 Tom Wheeler. All Rights 
 * Reserved. Any future updates to this code will be made available at 
 * http://www.tomwheeler.com/netbeans/
 */

package com.tomwheeler.example.tdlfile;

import com.tomwheeler.example.tdlfile.intf.TodoList;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.util.actions.NodeAction;

/**
 * <p>
 * This is an action that will add a new item to the currently selected 
 * TODO list.
 * </p>
 * 
 * @author <a href="http://www.tomwheeler.com/netbeans/">Tom Wheeler</a>
 */
public final class AddItemAction extends NodeAction {
    
    /** the main business logic of this class */
    protected void performAction(Node[] activatedNodes) {
        Node firstNode = activatedNodes[0];
        
        Lookup nodeLookup = firstNode.getLookup();
        TodoList todoList = (TodoList) nodeLookup.lookup(TodoList.class);
        if (todoList == null) {
            // we checked for this in enabled(Node[]), so it should not be null
            // unless the lookup was recently changed.  But it's best to be safe.
            System.err.println("Selected node's lookup does not contain a TodoList");
            return;
        }
        
        // create a new (default) item that the user can modify
        todoList.addItem();
    }
    
    /** identifies this action (for example, in a menu) */
    public String getName() {
        return NbBundle.getMessage(AddItemAction.class, "CTL_AddItem");
    }
    
    /** 
     * This identifies the icon for this action.  May or may not be shown 
     * depending on where the action is used (in a menu, toolbar, etc.)
     */
    protected String iconResource() {
        return "com/tomwheeler/example/tdlfile/resources/tdlitem.png";
    }
    
    public HelpCtx getHelpCtx() {
        // we don't have context-sensitive help for this action
        return HelpCtx.DEFAULT_HELP;
    }
    
    protected boolean asynchronous() {
        // it doesn't take long to add a new item, so it's safe to run this
        // event-dispatching thread.  If we had a long-running operation, we
        // might want to run it in a separate thread by setting this value to
        // true, but make sure all GUI updates to the are done in the 
        // event-dispatching thread.  See org.openide.util.AsyncGUIJob and/or
        // org.openide.util.Mutex for classes you might use to do this, and
        // then search the NetBeans IDE source code for examples that use them.
        return false;
    }
    
    /** 
     * determines whether this action is enabled, based on the state of the 
     * currently selected nodes 
     */
    protected boolean enable(Node[] activatedNodes) {
        // this action is enabled only when exactly one node is selected
        if (activatedNodes == null || activatedNodes.length != 1) {
            return false;
        }
        
        // ...and that node's lookup contains a valid TodoList to which we can 
        // add an item.
        Lookup nodeLookup = activatedNodes[0].getLookup();
        return nodeLookup.lookup(TodoList.class) != null;
    }
}
