/*
 *                 Sun Public License Notice
 *
 * The contents of this file are subject to the Sun Public License
 * Version 1.0 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.sun.com/
 *
 *
 * The Original Code is NetBeans. The Initial Developer of the Original
 * Code is Tom Wheeler. Portions Copyright 2006 Tom Wheeler. All Rights 
 * Reserved. Any future updates to this code will be made available at 
 * http://www.tomwheeler.com/netbeans/
 */

package com.tomwheeler.example.tdlfile;

import java.awt.BorderLayout;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.Serializable;
import javax.swing.ActionMap;
import javax.swing.JLabel;
import org.openide.explorer.view.NodeTableModel;
import org.openide.ErrorManager;
import org.openide.explorer.ExplorerManager;
import org.openide.explorer.ExplorerUtils;
import org.openide.explorer.view.TreeTableView;
import org.openide.nodes.Node;
import org.openide.windows.TopComponent;
import org.openide.windows.WindowManager;

/**
 * <p>
 * This class is a TopComponent that can edit the entire TodoList by showing the
 * items in a hierarchical table format (TreeTableView).
 * </p>
 * 
 * @author <a href="http://www.tomwheeler.com/netbeans/">Tom Wheeler</a>
 */
public final class TodoListEditor extends TopComponent implements ExplorerManager.Provider {
                                                                                                                                                 
    // TODO: This should probably be a CloneableTopComponent and not a singleton
                                                                                                                                                 
    private static final long serialVersionUID = 1L;
                                                                                                                                                 
    private static TodoListEditor instance;
    
    /** path to the icon used by the component and its open action */
//    static final String ICON_PATH = "SET/PATH/TO/ICON/HERE";
                                                                                                                                                 
    private static final String PREFERRED_ID = "todoeditor";
     
    private final ExplorerManager manager = new ExplorerManager();
    private TreeTableView view;
    private NodeTableModel nodeTableModel;
     
    private TodoListEditor() {
        initComponents();
        // TODO: maybe show the file or node name currently being edited
        setName("TodoList Table");
        setToolTipText("TodoList Table"); 
 
        ActionMap map = getActionMap();
        map.put("delete", ExplorerUtils.actionDelete(manager, true)); //NOI18N
        associateLookup(ExplorerUtils.createLookup(manager, map));
    }
     
    public void setRootNode(Node rootNode) {
        this.removeAll();
         
        if (rootNode != null) {
            manager.setRootContext(rootNode);

            nodeTableModel = new NodeTableModel();
            nodeTableModel.setNodes(rootNode.getChildren().getNodes());
            
            Node[] nodes = rootNode.getChildren().getNodes();
            Node.Property[] np = nodes[0].getPropertySets()[0].getProperties();
            nodeTableModel.setProperties(np);

            view = new TreeTableView(nodeTableModel);
            view.setPopupAllowed(true);
            
            add(view, BorderLayout.CENTER);
        } else {
            add(new JLabel("Invalid Todo List Item Data"), BorderLayout.CENTER);
        }
    }
     
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
 
        setLayout(new java.awt.BorderLayout());
 
    }
    // </editor-fold>//GEN-END:initComponents
     
     
    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables
     
    /**
     * Gets default instance. Do not use directly: reserved for *.settings files only,
     * i.e. deserialization routines; otherwise you could get a non-deserialized instance.
     * To obtain the singleton instance, use {@link findInstance}.
     */
    public static synchronized TodoListEditor getDefault() {
        if (instance == null) {
            instance = new TodoListEditor();
        }
        return instance;
    }
     
    /**
     * Obtain the CsvTableTopComponent instance. Never call {@link #getDefault} directly!
     */
    public static synchronized TodoListEditor findInstance() {
        TopComponent win = WindowManager.getDefault().findTopComponent(PREFERRED_ID);
        if (win == null) {
            ErrorManager.getDefault().log(ErrorManager.WARNING, 
                    "Cannot find Viewer component. It will not be located properly in the window system.");
            return getDefault();
        }
        if (win instanceof TodoListEditor) {
            return (TodoListEditor)win;
        }
        ErrorManager.getDefault().log(ErrorManager.WARNING, 
                "There seem to be multiple components with the '" + PREFERRED_ID 
                + "' ID. That is a potential source of errors and unexpected behavior.");
        return getDefault();
    }
     
    public int getPersistenceType() {
        return TopComponent.PERSISTENCE_ALWAYS;
    }
     
    /** replaces this in object stream */
    public Object writeReplace() {
        return new ResolvableHelper();
    }
     
    protected String preferredID() {
        return PREFERRED_ID;
    }
 
    public ExplorerManager getExplorerManager() {
        return manager;
    }
     
    final static class ResolvableHelper implements Serializable {
        private static final long serialVersionUID = 1L;
        public Object readResolve() {
            return TodoListEditor.getDefault();
        }
    }     
}
