/*
 *                 Sun Public License Notice
 *
 * The contents of this file are subject to the Sun Public License
 * Version 1.0 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.sun.com/
 *
 *
 * The Original Code is NetBeans. The Initial Developer of the Original
 * Code is Tom Wheeler. Portions Copyright 2006 Tom Wheeler. All Rights 
 * Reserved. Any future updates to this code will be made available at 
 * http://www.tomwheeler.com/netbeans/
 */

package com.tomwheeler.example.tdlfile;

import java.io.IOException;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiDataObject;
import org.openide.loaders.UniFileLoader;
import org.openide.util.NbBundle;

/**
 * <p>
 * This helps to configure NetBeans to recognize TodoList files, based
 * on their file extension.  It was generated by the File Type wizard in the 
 * NetBeans 5.0 IDE, and I didn't need to change anything afterwards.
 * </p>
 * 
 * @author <a href="http://www.tomwheeler.com/netbeans/">Tom Wheeler</a>
 */
public class TodoListFileDataLoader extends UniFileLoader {
    
    public static final String REQUIRED_MIME = "text/x-tdl";
    
    private static final long serialVersionUID = 1L;
    
    public TodoListFileDataLoader() {
        super("com.tomwheeler.example.tdlfile.TodoListFileDataObject");
    }
    
    protected String defaultDisplayName() {
        return NbBundle.getMessage(TodoListFileDataLoader.class, "LBL_TodoListFile_loader_name");
    }
    
    protected void initialize() {
        super.initialize();
        getExtensions().addMimeType(REQUIRED_MIME);
    }
    
    protected MultiDataObject createMultiObject(FileObject primaryFile) throws DataObjectExistsException, IOException {
        return new TodoListFileDataObject(primaryFile, this);
    }
    
    protected String actionsContext() {
        return "Loaders/" + REQUIRED_MIME + "/Actions";
    }
    
}
