/*
 *                 Sun Public License Notice
 *
 * The contents of this file are subject to the Sun Public License
 * Version 1.0 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.sun.com/
 *
 *
 * The Original Code is NetBeans. The Initial Developer of the Original
 * Code is Tom Wheeler. Portions Copyright 2006 Tom Wheeler. All Rights 
 * Reserved. Any future updates to this code will be made available at 
 * http://www.tomwheeler.com/netbeans/
 */

package com.tomwheeler.example.tdlfile.gui;

import com.tomwheeler.example.tdlfile.intf.TodoListItem;
import java.awt.BorderLayout;
import java.io.Serializable;
import javax.swing.JLabel;
import org.openide.ErrorManager;
import org.openide.util.NbBundle;
import org.openide.util.Utilities;
import org.openide.windows.TopComponent;
import org.openide.windows.WindowManager;

/**
 * <p>
 * This class is a TopComponent (main window) for editing a single item in the
 * Todo List.  It does not contain any GUI code itself, at least the way I 
 * coded it.  The GUI is handled through the <code>TodoListItemEditorForm</code>
 * and <code>TodoListItemEditorController</code> classes in this package.
 * </p>
 *
 * @author <a href="http://www.tomwheeler.com/netbeans/">Tom Wheeler</a>
 */
final class TodoListItemEditorTopComponent extends TopComponent {
    
    private static final long serialVersionUID = 1L;
    
    private static TodoListItemEditorTopComponent instance;
    /** path to the icon used by the component and its open action */
    static final String ICON_PATH = "com/tomwheeler/example/tdlfile/gui/resources/tdlitem.png";
    
    private static final String PREFERRED_ID = "TodoListItemEditorTopComponent";
    
    private TodoListItemEditorTopComponent() {
        initComponents();
        setName(NbBundle.getMessage(TodoListItemEditorTopComponent.class, "CTL_TodoListItemEditorTopComponent"));
        setToolTipText(NbBundle.getMessage(TodoListItemEditorTopComponent.class, "HINT_TodoListItemEditorTopComponent"));
        setIcon(Utilities.loadImage(ICON_PATH, true));

        // add
        setLayout(new BorderLayout());
        add(new JLabel("No TodoListItem available"), BorderLayout.CENTER);
    }
    
    public void setTodoListItem(TodoListItem item) {
        this.removeAll();
        
        TodoListItemEditorController controller = new TodoListItemEditorController();
        controller.setTodoListItem(item);
        TodoListItemEditorForm form = controller.getForm();
        add(form, BorderLayout.CENTER);
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(0, 400, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(0, 300, Short.MAX_VALUE)
        );
    }// </editor-fold>//GEN-END:initComponents
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables
    
    /**
     * Gets default instance. Do not use directly: reserved for *.settings files only,
     * i.e. deserialization routines; otherwise you could get a non-deserialized instance.
     * To obtain the singleton instance, use {@link findInstance}.
     */
    public static synchronized TodoListItemEditorTopComponent getDefault() {
        if (instance == null) {
            instance = new TodoListItemEditorTopComponent();
        }
        return instance;
    }
    
    /**
     * Obtain the TodoListItemEditorTopComponent instance. Never call {@link #getDefault} directly!
     */
    public static synchronized TodoListItemEditorTopComponent findInstance() {
        TopComponent win = WindowManager.getDefault().findTopComponent(PREFERRED_ID);
        if (win == null) {
            ErrorManager.getDefault().log(ErrorManager.WARNING, "Cannot find TodoListItemEditor component. It will not be located properly in the window system.");
            return getDefault();
        }
        if (win instanceof TodoListItemEditorTopComponent) {
            return (TodoListItemEditorTopComponent)win;
        }
        ErrorManager.getDefault().log(ErrorManager.WARNING, "There seem to be multiple components with the '" + PREFERRED_ID + "' ID. That is a potential source of errors and unexpected behavior.");
        return getDefault();
    }
    
    public int getPersistenceType() {
        return TopComponent.PERSISTENCE_ALWAYS;
    }
    
    public void componentOpened() {
        // TODO add custom code on component opening
    }
    
    public void componentClosed() {
        // TODO add custom code on component closing
    }
    
    /** replaces this in object stream */
    public Object writeReplace() {
        return new ResolvableHelper();
    }
    
    protected String preferredID() {
        return PREFERRED_ID;
    }
    
    final static class ResolvableHelper implements Serializable {
        private static final long serialVersionUID = 1L;
        public Object readResolve() {
            return TodoListItemEditorTopComponent.getDefault();
        }
    }
    
}
